<?php

namespace Drupal\overview_builder_example\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class AdvancedNodeOverviewFiltersForm.
 *
 * @package Drupal\overview_builder_example\Form
 */
class AdvancedNodeOverviewFiltersForm extends FormBase {

  /**
   * The taxonomy term storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $taxonomyTermStorage;

  /**
   * AdvancedNodeOverviewFiltersForm constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->taxonomyTermStorage = $entityTypeManager->getStorage('taxonomy_term');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'advanced_node_overview_filters_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['#method'] = 'GET';

    $form['tag'] = [
      '#type' => 'select',
      '#title' => $this->t('Tags'),
      '#empty_option' => $this->t('- Choose -'),
      '#options' => $this->getNewsTagOptions(),
      '#default_value' => $this->getRequest()->query->get('tag', []),
      '#wrapper_attributes' => ['class' => ['col-lg']],
    ];

    $form['category'] = [
      '#type' => 'select',
      '#title' => $this->t('Category'),
      '#empty_option' => $this->t('- Choose -'),
      '#options' => $this->getNewsCategoryOptions(),
      '#default_value' => $this->getRequest()->query->get('category', []),
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Search'),
      // Prevent op from showing up in URL.
      '#name' => '',
    ];

    $form['#cache']['contexts'] = [
      'languages',
      'url.query_args',
    ];
    $form['#cache']['tags'] = [
      'node_list',
    ];

    return $form;
  }

  /**
   * Build the news tag options.
   *
   * @return array
   *   An array containing the news tag option as key and label as value.
   */
  protected function getNewsTagOptions(): array {
    $options = [];
    /** @var \Drupal\taxonomy\TermInterface[] $news_tags */
    $news_tags = $this->taxonomyTermStorage->loadByProperties(['vid' => 'news_tag']);

    foreach ($news_tags as $news_tag) {
      $options[$news_tag->id()] = $news_tag->label();
    }

    return $options;
  }

  /**
   * Build the news tag options.
   *
   * @return array
   *   An array containing the news tag option as key and label as value.
   */
  protected function getNewsCategoryOptions(): array {
    $options = [];
    /** @var \Drupal\taxonomy\TermInterface[] $news_tags */
    $news_tags = $this->taxonomyTermStorage->loadByProperties(['vid' => 'news_category']);

    foreach ($news_tags as $news_tag) {
      $options[$news_tag->id()] = $news_tag->label();
    }

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
  }

}
