<?php

namespace Drupal\overview_builder_test\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class AdvancedCustomNewsOverviewFiltersForm.
 *
 * @package Drupal\overview_builder_test\Form
 */
class AdvancedCustomNewsOverviewFiltersForm extends FormBase {

  /**
   * The taxonomy term storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $taxonomyTermStorage;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->taxonomyTermStorage = $entityTypeManager->getStorage('taxonomy_term');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'advanced_custom_news_overview_filters_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['#method'] = 'GET';

    $form['news_category'] = [
      '#type' => 'select',
      '#title' => $this->t('News category'),
      '#options' => $this->getNewsCategoryOptions(),
      '#default_value' => $this->getRequest()->query->get('news_category', []),
      '#empty_option' => $this->t('- Choose -'),
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
      // Prevent op from showing up in URL.
      '#name' => '',
    ];

    $form['#cache']['contexts'] = ['languages', 'url.query_args'];
    $form['#cache']['tags'] = ['node_list'];
    $form['#pre_render'][] = [$this, 'preRenderRemoveDefaultStuff'];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * Build the news category options.
   *
   * @return array
   *   An array of news categories.
   */
  protected function getNewsCategoryOptions(): array {
    $options = [];

    $terms = $this->taxonomyTermStorage->loadByProperties(['vid' => 'news_category']);
    foreach ($terms as $term) {
      $options[$term->id()] = $term->label();
    }

    return $options;
  }

  /**
   * Since the exposed form is a GET form, remove the tokens.
   *
   * @param array $form
   *   The form.
   *
   * @return array
   *   The altered form.
   */
  public function preRenderRemoveDefaultStuff(array $form): array {
    unset($form['form_token'], $form['form_build_id'], $form['form_id']);
    return $form;
  }

}
